Interface BijectiveFunction<B,I>

Type Parameters:
B - The type of the bijective function's result.
I - The type of the bijective function's input (being the inverse function's output type).
All Known Subinterfaces:
Invertible<B,I>
All Known Implementing Classes:
InvertibleComposite
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface BijectiveFunction<B,I>
A BijectiveFunction provides methods to apply a bijective function (on the inverse function's return vale).