-
- All Known Subinterfaces:
CrcAlgorithmAccessor.CrcAlgorithmProperty,CrcMixin
- All Known Implementing Classes:
AbstractCrcMixin
public interface CrcAlgorithmAccessorProvides an accessor for aCrcAlgorithmproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceCrcAlgorithmAccessor.CrcAlgorithmBuilder<B extends CrcAlgorithmAccessor.CrcAlgorithmBuilder<B>>Provides a builder method for aCrcAlgorithmproperty returning the builder for applying multiple build operations.static interfaceCrcAlgorithmAccessor.CrcAlgorithmMutatorProvides a mutator for aCrcAlgorithmproperty.static interfaceCrcAlgorithmAccessor.CrcAlgorithmPropertyProvides aCrcAlgorithmproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description CrcAlgorithmgetCrcAlgorithm()Retrieves the value from theCrcAlgorithmproperty.
-
-
-
Method Detail
-
getCrcAlgorithm
CrcAlgorithm getCrcAlgorithm()
Retrieves the value from theCrcAlgorithmproperty.- Returns:
- The name stored by the
CrcAlgorithmproperty.
-
-