Interface InverseFunction<I,B>

Type Parameters:
I - The type of the inverse function's result.
B - The type of the inverse function's input (being the bijective function's output type).
All Known Subinterfaces:
Invertible<B,I>
All Known Implementing Classes:
InvertibleComposite
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface InverseFunction<I,B>
A InverseFunction provides methods to apply an inverse function (on the bijective function's return vale).