-
- All Known Subinterfaces:
PaddingCharAccessor.PaddingCharProperty
public interface PaddingCharAccessorProvides an accessor for a padding char property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePaddingCharAccessor.PaddingCharBuilder<B extends PaddingCharAccessor.PaddingCharBuilder<B>>Provides a builder method for a padding char property returning the builder for applying multiple build operations.static interfacePaddingCharAccessor.PaddingCharMutatorProvides a mutator for a padding char property.static interfacePaddingCharAccessor.PaddingCharPropertyProvides a padding char property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description chargetPaddingChar()Retrieves the value from the padding char property.
-