Uses of Interface
org.refcodes.numerical.CrcAlgorithm
-
-
Uses of CrcAlgorithm in org.refcodes.numerical
Classes in org.refcodes.numerical that implement CrcAlgorithm Modifier and Type Class Description classCrcAlgorithmConfigEnumeration with CRC implementations hacked together from sources "out there".classCrcAlgorithmImplImplementation of theCrcAlgorithminterface.Fields in org.refcodes.numerical declared as CrcAlgorithm Modifier and Type Field Description protected CrcAlgorithmAbstractCrcMixin. _crcAlgorithmMethods in org.refcodes.numerical that return CrcAlgorithm Modifier and Type Method Description CrcAlgorithmAbstractCrcMixin. getCrcAlgorithm()Retrieves the value from theCrcAlgorithmproperty.CrcAlgorithmCrcAlgorithmAccessor. getCrcAlgorithm()Retrieves the value from theCrcAlgorithmproperty.default CrcAlgorithmCrcAlgorithmAccessor.CrcAlgorithmProperty. letCrcAlgorithm(CrcAlgorithm aCrcAlgorithm)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCrcAlgorithm(setter) as ofCrcAlgorithmAccessor.CrcAlgorithmMutator.setCrcAlgorithm(CrcAlgorithm)and returns the very same value (getter).Methods in org.refcodes.numerical with parameters of type CrcAlgorithm Modifier and Type Method Description default CrcAlgorithmCrcAlgorithmAccessor.CrcAlgorithmProperty. letCrcAlgorithm(CrcAlgorithm aCrcAlgorithm)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCrcAlgorithm(setter) as ofCrcAlgorithmAccessor.CrcAlgorithmMutator.setCrcAlgorithm(CrcAlgorithm)and returns the very same value (getter).voidCrcAlgorithmAccessor.CrcAlgorithmMutator. setCrcAlgorithm(CrcAlgorithm aCrcAlgorithm)Sets the value for theCrcAlgorithmproperty.BCrcAlgorithmAccessor.CrcAlgorithmBuilder. withCrcAlgorithm(CrcAlgorithm aCrcAlgorithm)Sets the value for theCrcAlgorithmproperty.Constructors in org.refcodes.numerical with parameters of type CrcAlgorithm Constructor Description AbstractCrcMixin(CrcAlgorithm aCrcAlgorithm, org.refcodes.mixin.ConcatenateMode aCrcChecksumConcatenateMode, ChecksumValidationMode aChecksumValidationMode, Endianess aEndianess)Constructs an according instance from the given arguments.
-