Uses of Enum Class
org.refcodes.numerical.CrcAlgorithmConfig
-
Uses of CrcAlgorithmConfig in org.refcodes.numerical
Methods in org.refcodes.numerical that return CrcAlgorithmConfigModifier and TypeMethodDescriptionCrcSize.getCrcAlgorithms()Retrieves theCrcAlgorithmConfigimplementations as of the accordingCrcSize.static CrcAlgorithmConfigReturns the enum constant of this class with the specified name.static CrcAlgorithmConfig[]CrcAlgorithmConfig.values()Returns an array containing the constants of this enum class, in the order they are declared.