Uses of Interface
org.refcodes.numerical.InverseFunction
-
-
Uses of InverseFunction in org.refcodes.numerical
Subinterfaces of InverseFunction in org.refcodes.numerical Modifier and Type Interface Description interfaceInvertible<B,I>AInvertibleprovides methods to apply a bijective function on a value as well as an inverse function (on the bijective function's return vale).Classes in org.refcodes.numerical that implement InverseFunction Modifier and Type Class Description classInvertibleComposite<B,I>TheInvertibleCompositeimplements theInvertibleand is composed of aBijectiveFunctionand the accordingInverseFunction.Constructors in org.refcodes.numerical with parameters of type InverseFunction Constructor Description InvertibleComposite(BijectiveFunction<B,I> aBijectiveFunction, InverseFunction<I,B> aInverseFunction)Constructs theInvertibleCompositefrom the providedBijectiveFunctionand the accordingInverseFunction.
-