Uses of Enum
org.refcodes.numerical.CrcAlgorithmConfig
-
Uses of CrcAlgorithmConfig in org.refcodes.numerical
Methods in org.refcodes.numerical that return CrcAlgorithmConfigModifier and TypeMethodDescriptionCrcSize.getCrcAlgorithms()Retrieves theCrcAlgorithmConfigimplementations as of the accordingCrcSize.static CrcAlgorithmConfigReturns the enum constant of this type with the specified name.static CrcAlgorithmConfig[]CrcAlgorithmConfig.values()Returns an array containing the constants of this enum type, in the order they are declared.