Uses of Class
org.refcodes.numerical.CrcAlgorithmConfig
-
-
Uses of CrcAlgorithmConfig in org.refcodes.numerical
Methods in org.refcodes.numerical that return CrcAlgorithmConfig Modifier and Type Method Description CrcAlgorithmConfig[]CrcSize. getCrcAlgorithms()Retrieves theCrcAlgorithmConfigimplementations as of the accordingCrcSize.static CrcAlgorithmConfigCrcAlgorithmConfig. valueOf(String name)Returns the enum constant of this type with the specified name.static CrcAlgorithmConfig[]CrcAlgorithmConfig. values()Returns an array containing the constants of this enum type, in the order they are declared.
-